<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * Fire to add support for third party plugin
 *
 * @since BuddyBoss 1.2.2
 */
function buddyboss_theme_helper_plugins_loaded_callback() {

	if ( function_exists( 'buddypress' ) && function_exists( 'is_plugin_active' ) ) {
		/**
		 * Include plugin when plugin is activated
		 *
		 * Support MemberPress + BuddyPress Integration
		 */
		if ( is_plugin_active( 'memberpress-buddypress/main.php' ) ) {
			/**
			 * This action is use when admin bar is Disable
			 */
			add_action( 'buddyboss_theme_after_bb_profile_menu', 'buddyboss_theme_helper_add_buddyboss_menu_for_memberpress_buddypress', 100 );
		}

		/**
		 * Support WPML Multilingual CMS.
		 *
		 * This code provides support for WPML Multilingual CMS by adding necessary filters to modify
		 * navigation menu attributes and icons when the WPML plugin is active.
		 */
		if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
			add_filter( 'bb_buddypanel_nav_menu_link_attributes', 'bb_theme_set_wpml_nav_menu_link_attributes' );
			add_filter( 'bb_theme_nav_menu_item_add_icon', 'bb_theme_add_wpml_nav_menu_item_icon', 10, 2 );
			add_filter( 'bb_theme_buddypanel_nav_menu_item_icon', 'bb_theme_set_wpml_nav_menu_item_icon_class', 10, 2 );
			add_filter( 'bb_theme_sub_nav_menu_wrap_item_icon', 'bb_theme_set_wpml_nav_menu_item_icon_class', 10, 2 );
		}
	}
}

add_action( 'init', 'buddyboss_theme_helper_plugins_loaded_callback', 100 );

/**
 * Add Menu in Admin section for MemberPress + BuddyPress Integration plugin
 *
 * @since BuddyBoss 1.2.2
 *
 * @param $menus
 */
function buddyboss_theme_helper_add_buddyboss_menu_for_memberpress_buddypress() {
	global $bp;

	$main_slug = apply_filters( 'mepr-bp-info-main-nav-slug', 'mp-membership' );
	$name      = apply_filters( 'mepr-bp-info-main-nav-name', _x( 'Membership', 'ui', 'buddyboss-theme' ) );
	?>
    <li id="wp-admin-bar-mp-membership" class="menupop">
        <a class="ab-item" aria-haspopup="true" href="<?php echo $bp->loggedin_user->domain . $main_slug . '/'; ?>">
            <span class="wp-admin-bar-arrow" aria-hidden="true"></span><?php echo $name; ?>
        </a>
        <div class="ab-sub-wrapper">
            <ul id="wp-admin-bar-mp-membership-default" class="ab-submenu">
                <li id="wp-admin-bar-mp-info">
                    <a class="ab-item" href="<?php echo $bp->loggedin_user->domain . $main_slug . '/'; ?>">
						<?php echo _x( 'Info', 'ui', 'buddyboss-theme' ); ?>
                    </a>
                </li>
                <li id="wp-admin-bar-mp-subscriptions">
                    <a class="ab-item"
                       href="<?php echo $bp->loggedin_user->domain . $main_slug . '/mp-subscriptions/'; ?>">
						<?php echo _x( 'Subscriptions', 'ui', 'buddyboss-theme' ); ?>
                    </a>
                </li>
                <li id="wp-admin-bar-mp-payments">
                    <a class="ab-item" href="<?php echo $bp->loggedin_user->domain . $main_slug . '/mp-payments/'; ?>">
						<?php echo _x( 'Payments', 'ui', 'buddyboss-theme' ); ?>
                    </a>
                </li>
            </ul>
        </div>
    </li>
	<?php
}

/**
 * Function to compatible with WPML menu tooltips.
 *
 * @since 2.5.60
 *
 * @param array $atts The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
 *
 * @return array The array of menu item attributes.
 */
function bb_theme_set_wpml_nav_menu_link_attributes( $atts ) {

	if ( ! empty( $atts['data-balloon'] ) ) {
		$atts['data-balloon'] = wp_strip_all_tags( $atts['data-balloon'] );
	}

	return $atts;
}

/**
 * Function to add icon to WPML menu item.
 *
 * @since 2.5.60
 *
 * @param string  $icon Menu icon.
 * @param integer $id   Menu item ID.
 *
 * @return string The menu item icon.
 */
function bb_theme_add_wpml_nav_menu_item_icon( $icon, $id ) {
	if ( ! empty( $id ) && str_contains( $id, 'wpml-' ) ) {
		$icon = '<i class="_mi _before buddyboss bb-icon-l bb-icon-globe"></i>';
	}

	return $icon;
}

/**
 * Function to set icon to WPML menu item.
 *
 * @since 2.5.60
 *
 * @param string  $icon Menu icon.
 * @param WP_Post $item Menu item data object.
 */
function bb_theme_set_wpml_nav_menu_item_icon_class( $icon, $item ) {
	if ( isset( $item->classes ) && is_array( $item->classes ) && in_array( 'wpml-ls-item', $item->classes, true ) ) {
		$icon = 'bb-icon-globe';
	}

	return $icon;
}
